==> tellico_0.13.3.orig.tar.gz: tellico-0.13.3/src/translators/tellicoimporter.h <==
/***************************************************************************
    copyright            : (C) 2003-2004 by Robby Stephenson
    email                : robby@periapsis.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of version 2 of the GNU General Public License as  *
 *   published by the Free Software Foundation;                            *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICOIMPORTER_H
#define TELLICOIMPORTER_H

#include "dataimporter.h"

#include <qdom.h>

namespace Tellico {
  namespace Import {

/**
 * Reading the @ref Tellico data files is done by the TellicoImporter.
 *
 * @author Robby Stephenson
 * @version $Id: tellicoimporter.h 921 2004-10-13 06:36:33Z robby $
 */
class TellicoImporter : public DataImporter {
Q_OBJECT

public:
  /**
   * @param url The tellico data file.
   */
  TellicoImporter(const KURL& url);
  /**
   * Constructor used to convert arbitrary text to a @ref Collection
   *
   * @param text The text
   */
  TellicoImporter(const QString& text);

  /**
   */
  virtual Data::Collection* collection();

private:
  void loadXMLData(const QByteArray& data, bool loadImages);
  void loadZipData(const QByteArray& data);

  void readField(unsigned syntaxVersion, const QDomElement& elem);
  void readEntry(unsigned syntaxVersion, const QDomNode& elem);
  void readImage(const QDomElement& elem);

  Data::Collection* m_coll;
  QString m_namespace;
};

  } // end namespace
} // end namespace
#endif

==> tellico_1.0.orig.tar.gz: tellico-1.0/src/translators/tellicoimporter.h <==
/***************************************************************************
    copyright            : (C) 2003-2005 by Robby Stephenson
    email                : robby@periapsis.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of version 2 of the GNU General Public License as  *
 *   published by the Free Software Foundation;                            *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_IMPORTER_H
#define TELLICO_IMPORTER_H

#include "dataimporter.h"
#include "../entry.h"
#include "../datavectors.h"

#include <qdom.h>

namespace Tellico {
  namespace Import {

/**
 * Reading the @ref Tellico data files is done by the TellicoImporter.
 *
 * @author Robby Stephenson
 */
class TellicoImporter : public DataImporter {
Q_OBJECT

public:
  enum Format { Unknown, Error, XML, Zip };

  /**
   * @param url The tellico data file.
   */
  TellicoImporter(const KURL& url, bool loadAllImages=true);
  /**
   * Constructor used to convert arbitrary text to a @ref Collection
   *
   * @param text The text
   */
  TellicoImporter(const QString& text);

  /**
   * sometimes, a new document format might add data
   */
  bool modifiedOriginal() const { return m_modified; }

  /**
   */
  virtual Data::Collection* collection();
  Format format() const { return m_format; }

  /**
   */
  static bool loadImage(const KURL& url, const QString& id);

private:
  void loadXMLData(const QByteArray& data, bool loadImages);
  void loadZipData();

  void readField(unsigned syntaxVersion, const QDomElement& elem);
  void readEntry(unsigned syntaxVersion, const QDomElement& elem);
  void readImage(const QDomElement& elem);
  void readFilter(const QDomElement& elem);
  void readBorrower(const QDomElement& elem);
  void addDefaultFilters();

  Data::Collection* m_coll;
  bool m_loadAllImages;
  QString m_namespace;
  Format m_format;
  bool m_modified;
};

  } // end namespace
} // end namespace
#endif
